**Reguli recomandate pentru adaptarea aplicatiei la modelul dvs de factura in Excel:**

* fiecare parametru are un hep scurt (liniile ce incep cu caracterul `#`) - citi-l inainte de a modifica uun parametru
* nu schimbati numele parametrilor asa cum este el specificat inainte de semnul egal (`=`)
* listele sunt incluse intre paranteze drepte (`[...]`) si elementele lor sunt separate prin caracterul virgula (`,`)
* sirurile de caractere sunt incluse intre ghilimele (caracterul `"`)
* daca doriti stergerea unei listei (de ex daca nu doriti nici o optiune pentru acea lista) doar lasati acel parametru cu valoarea `[]` - nu stergeti in nici un caz acel parametru
* nu adaugati parametrii suplimentari (altii decit cei specificati aici), acestia nu vor fi utilizati fara a modifica aplicatia (de asemenea riscati sa induceti erori in cod)
* pentru datele calendaristice in celulul Excel a se utiliza formatul standard de data (`date`) si modificati formatul de afisare in formatul dorit pe factura tiparibila



___(en-us) Recommended rules to configure the application to your Excel invoice model:___

* each parameter has a short help (lines starting with `#` character) - read it before changing that parameter
* do not change parametrs name as specified before equal (`=`) sign
* lists are enclosed in sqaured brackets (`[...]`) and items are separated by comma character (`,`)
* strings are enclosed in `"` characters
* if you want to clear a list (for example you do not wants any options inside) just let it as `<PARAMETR NAME> = []` - do not drop that parameter
* do not add supplementary parameters, they will not be used without software changes (also risk to induce potential errors)
* for calendaristic dates Excel cells use `date` format and change it as display option to show wanted format

